@@ -177,6 +177,8 @@ the C<$current_emp> object.
 
 sub determine_employee {
     my $s_key = shift;
+    $log->debug( "Entering " . __PACKAGE__ . "::determine_employee with \$s_key ->" .
+        ( defined( $s_key ) ? $s_key : "undef" ) . "<-" );
 
     my $status = ( $s_key )
         ? lookup_employee( key => $s_key, minimal => 1 )
@@ -214,10 +216,13 @@ sub lookup_employee {
     my $status;
     if ( $key_spec =~ m/^emp/i ) {
         $status = send_req( 'GET', "employee/nick/$key$minimal" );
-        if ( $status->not_ok and ( $status->{'http_code'} == 404 or $status->{'http_code'} == 403 ) ) {
-            $status = send_req( 'GET', "employee/sec_id/$key$minimal" );
-            if ( $status->not_ok and $status->{'http_code'} != 500 and looks_like_number( $key ) ) {
-                $status = send_req( 'GET', "employee/eid/$key$minimal" );
+        BREAK_OUT: {
+            last BREAK_OUT if $status->not_ok and $status->{'http_code'} == 403;
+            if ( $status->not_ok and $status->{'http_code'} == 404 ) {
+                $status = send_req( 'GET', "employee/sec_id/$key$minimal" );
+                if ( $status->not_ok and $status->{'http_code'} != 500 and looks_like_number( $key ) ) {
+                    $status = send_req( 'GET', "employee/eid/$key$minimal" );
+                }
             }
         }
     } elsif ( $key_spec =~ m/^nic/i ) {
